@@ -7,7 +7,7 @@ from pandas.api.types import is_datetime64_any_dtype as is_datetime
 
 
 from cgdb.exceptions.ColumnNotFound import ColumnNotFoundException
-from cgdb.recources.dataSet import DataSets
+from cgdb.resources.dataSet import DataSets
 from cgdb.utils.ManagerMix import ManagerMix
 
 
@@ -264,13 +264,14 @@ class DataSetsManager(ManagerMix):
     #
     #     return json.dumps(out)
 
-    def create_data_set(self, station, element_code, aggregation, time_step_code, data_set_type="TECHNICAL", elementMarkOverride = None):
+    def create_data_set(self, station, element_code, aggregation, time_step_code, data_set_type="TECHNICAL", elementMarkOverride = None, description = None):
         element_context = self._client._element_contexts_manager.element_context_by_element(element_code, aggregation, time_step_code)
 
         url = station.url + "/data-sets"
 
         content = {"contextId": element_context.id,
                    "elementMarkOverride": elementMarkOverride,
-                   "dataSetType": data_set_type}
+                   "dataSetType": data_set_type,
+                   "description": description}
 
         self.post(url, json.dumps(content))
\ No newline at end of file
