@@ -1,4 +1,4 @@
-from cgdb.recources.element import Element
+from cgdb.resources.element import Element
 from cgdb.utils.ManagerMix import ManagerMix
 
 
